%global version 0.8.3
%global rpmrelease 4
%global debianrelease 0.8.1-4.1
# betarelease is either 0 or a snapshot date like 20160906
%global betarelease 0

# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: A SIP masquerading proxy with RTP support
Name: siproxd
Version: %{version}
%if "%{betarelease}" == "0"
Release: %{rpmrelease}%{?dist}
%else
Release: 0.%{betarelease}.%{rpmrelease}%{?dist}
%endif
License: GPL-2.0-only
Group: System Environment/Daemons
URL: http://siproxd.sourceforge.net/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
%if "%{betarelease}" == "0"
Source0: http://dl.sf.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
%else
Source0: http://siproxd.tuxworld.ch/siproxd-%{betarelease}.tar.gz
%endif
Source1: http://deb.debian.org/debian/pool/main/s/%{name}/%{name}_%{debianrelease}.debian.tar.gz
Source2: %{name}.%{_servicefile_postfix}
%if %{_has_systemd}
Source3: %{name}-tmpfiles.conf
%endif
Patch0: siproxd.plugin_fix_bogus_via.c.patch
Patch1: siproxd-0.8.3dev-startup.patch
# patches >=100 will/should be fixed in SCM
Patch100: siproxd-0.8.3dev-config.patch
Patch101: https://github.com/hb9xar/siproxd/commit/b0f4b1970167c5d15f8eeb44ce4e947f1df59769.patch
Patch102: https://github.com/hb9xar/siproxd/commit/1c01f3ec2993020ecf3e7a32d43a70f706bc9662.patch
Patch103: https://github.com/hb9xar/siproxd/commit/9d4c1ef1725ad0744a1b5ca300d5c30366931cf9_mod.patch
Patch104: https://github.com/hb9xar/siproxd/commit/9e05d8cba5c08a8233fa7015932b846e026be34d_mod.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: libosip2-devel >= 5.0.0, sed, docbook-utils
BuildRequires: sqlite-devel >= 3.3.6

%description
Siproxd is a proxy/masquerading daemon for the SIP protocol.
It handles registrations of SIP clients on a private IP network and
performs rewriting of the SIP message bodies to make SIP connections
work via a masquerading firewall (NAT). It allows SIP software
clients (like kphone, linphone) or SIP hardware clients (Voice over
IP phones which are SIP-compatible, such as those from Cisco,
Grandstream or Snom) to work behind an IP masquerading firewall
or NAT router.

%prep
%if "%{betarelease}" == "0"
%setup -q -a 1
%else
%setup -q -a 1 -n %{name}-%{version}dev
%endif
%patch0 -p1 -b .plugin_fix_bogus_via
%patch1 -p1 -b .startup

# preserve timestamp
%{__cp} -a doc/siproxd.conf.example doc/siproxd.conf.example.$$
%patch100 -p1 -b .config
touch -r doc/siproxd.conf.example.$$ doc/siproxd.conf.example
%{__rm} -f doc/siproxd.conf.example.$$

%patch101 -p1 -b .b0f4b1970167c5d15f8eeb44ce4e947f1df59769
%patch102 -p1 -b .1c01f3ec2993020ecf3e7a32d43a70f706bc9662
%patch103 -p1 -b .9d4c1ef1725ad0744a1b5ca300d5c30366931cf9
%patch104 -p1 -b .9e05d8cba5c08a8233fa7015932b846e026be34d

%build
%configure --libdir=%{_libexecdir} --disable-static
%{__make}

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}
 
%{__install} -d %{buildroot}%{_var}/lib/%{name}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}
%{__install} -d %{buildroot}%{_mandir}/man8

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p" docdir=%{_docdir}/%{name}-%{version}

%{__sed} \
  -e 's|^user.*=.*|user = %{name}|g' \
  -e 's|^pid_file.*=.*|pid_file = %{_pidbasedir}/%{name}/%{name}.pid|g' \
  -e 's|^plugindir.*=.*|plugindir=%{_libexecdir}/%{name}/|g' \
  %{buildroot}%{_sysconfdir}/%{name}.conf.example > %{buildroot}%{_sysconfdir}/%{name}.conf
touch -r %{buildroot}%{_sysconfdir}/%{name}.conf.example %{buildroot}%{_sysconfdir}/%{name}.conf
%{__rm} -f %{buildroot}%{_sysconfdir}/%{name}.conf.example

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p debian/%{name}.8 %{buildroot}%{_mandir}/man8/

for F in AUTHORS ChangeLog COPYING NEWS README RELNOTES TODO doc/FAQ doc/FLI4L_HOWTO.txt doc/KNOWN_BUGS doc/RFC3261_compliance.txt doc/sample_*.txt; do
  %{__install} -m 0644 -p "$F" %{buildroot}%{_docdir}/%{name}-%{version}/
done

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name} 2> /dev/null || :
getent passwd %{name} > /dev/null || \
  %{_sbindir}/useradd -g %{name} -s /sbin/nologin -r -c "Siproxd User" -d %{_var}/lib/%{name} %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-%{version}
%{_mandir}/man8/%{name}.8*
%attr(0755,root,root) %{_sbindir}/%{name}
%{_libexecdir}/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}
%endif
%config(noreplace) %{_sysconfdir}/%{name}.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}_passwd.cfg
%attr(0770,%{name},%{name}) %dir %{_var}/lib/%{name}
%attr(0775,root,%{name}) %dir %{_pidbasedir}/%{name}

%changelog
* Wed Jun 21 2023 Simon Matter <simon.matter@invoca.ch> 0.8.3-4
- change %{configure} -> %configure
- change to *.common.service systemd files
- remove eval where possible
- change to SPDX license tag
- fix building of beta releases

* Tue Nov 23 2021 Simon Matter <simon.matter@invoca.ch> 0.8.3-3
- rebuild with new libosip2 version
- add patches from git

* Wed Nov 11 2020 Simon Matter <simon.matter@invoca.ch> 0.8.3-2
- rebuild with new libosip2 version
- add patches from 0.8.4dev

* Tue Aug 25 2020 Simon Matter <simon.matter@invoca.ch> 0.8.3-1
- upgrade to 0.8.3

* Wed Apr 15 2020 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20200302.2
- add support for EL8

* Mon Mar 02 2020 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20200302.1
- upgrade to current 0.8.3dev snapshot

* Mon Mar 19 2018 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20180319.1
- upgrade to current 0.8.3dev snapshot

* Tue Nov 21 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20171121.1
- upgrade to current 0.8.3dev snapshot

* Thu Oct 12 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20171012.1
- upgrade to current 0.8.3dev snapshot

* Thu Oct 05 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20171005.1
- upgrade to current 0.8.3dev snapshot

* Wed Oct 04 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20171004.1
- upgrade to current 0.8.3dev snapshot

* Tue Oct 03 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20171003.1
- upgrade to current 0.8.3dev snapshot

* Mon Oct 02 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20171002.1
- upgrade to current 0.8.3dev snapshot

* Sat Sep 30 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170930.1
- upgrade to current 0.8.3dev snapshot

* Thu Sep 28 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170928.1
- upgrade to current 0.8.3dev snapshot

* Mon Aug 14 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170814.1
- upgrade to current 0.8.3dev snapshot

* Tue Jun 06 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170606.1
- upgrade to current 0.8.3dev snapshot

* Tue May 30 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170530.1
- upgrade to current 0.8.3dev snapshot

* Mon Apr 17 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170417.1
- upgrade to current 0.8.3dev snapshot

* Sat Apr 08 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170408.1
- upgrade to current 0.8.3dev snapshot

* Fri Apr 07 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170407.1
- upgrade to current 0.8.3dev snapshot

* Wed Mar 22 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170322.1
- upgrade to current 0.8.3dev snapshot

* Mon Mar 20 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170320.1
- upgrade to current 0.8.3dev snapshot

* Wed Mar 15 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170315.1
- upgrade to current 0.8.3dev snapshot

* Mon Mar 13 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170313.1
- upgrade to current 0.8.3dev snapshot

* Mon Mar 06 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170306.1
- upgrade to current 0.8.3dev snapshot

* Tue Feb 28 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170228.1
- upgrade to current 0.8.3dev snapshot

* Mon Feb 27 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170227.1
- upgrade to current 0.8.3dev snapshot

* Mon Feb 13 2017 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20170213.1
- upgrade to current 0.8.3dev snapshot

* Tue Oct 11 2016 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20161011.1
- upgrade to current 0.8.3dev snapshot

* Mon Sep 19 2016 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20160919.1
- upgrade to current 0.8.3dev snapshot

* Fri Sep 09 2016 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20160906.2
- add plugin_stats_pid patch

* Tue Sep 06 2016 Simon Matter <simon.matter@invoca.ch> 0.8.3-0.20160906.1
- upgrade to current 0.8.3dev snapshot

* Tue Sep 06 2016 Simon Matter <simon.matter@invoca.ch> 0.8.2-4
- support building of development snapshot

* Fri Aug 26 2016 Simon Matter <simon.matter@invoca.ch> 0.8.2-3
- backport patches from 0.8.3dev

* Mon Aug 22 2016 Simon Matter <simon.matter@invoca.ch> 0.8.2-2
- add plugin_logcall patch

* Mon Apr 18 2016 Simon Matter <simon.matter@invoca.ch> 0.8.2-1
- upgrade to 0.8.2

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 0.8.1-7
- small spec fixes for systemd

* Tue Feb 03 2015 Simon Matter <simon.matter@invoca.ch> 0.8.1-6
- add support for systemd

* Fri Sep 12 2014 Simon Matter <simon.matter@invoca.ch> 0.8.1-5
- fix manpage
- rebuild with libosip2-4.1.0

* Fri Dec 16 2011 Simon Matter <simon.matter@invoca.ch> 0.8.1-4
- rebuild with libosip2-3.6.0

* Wed Sep 14 2011 Simon Matter <simon.matter@invoca.ch> 0.8.1-3
- improve manpage

* Sat Sep 03 2011 Simon Matter <simon.matter@invoca.ch> 0.8.1-2
- put plugins into /usr/libexec

* Sat Sep 03 2011 Simon Matter <simon.matter@invoca.ch> 0.8.1-1
- initial build
